.. _spkg__cibuildwheel_local_a:

_cibuildwheel_local_a: Non-Python dependencies of packages for which we build platform wheels, side A
=====================================================================================================


Type
----

optional


Dependencies
------------

- :ref:`spkg_4ti2`
- :ref:`spkg_benzene`
- :ref:`spkg_bliss`
- :ref:`spkg_boost_cropped`
- :ref:`spkg_brial`
- :ref:`spkg_buckygen`
- :ref:`spkg_ccache`
- :ref:`spkg_cddlib`
- :ref:`spkg_cliquer`
- :ref:`spkg_coxeter3`
- :ref:`spkg_ecm`
- :ref:`spkg_gap`
- :ref:`spkg_gap_packages`
- :ref:`spkg_gap_pkg_cddinterface`
- :ref:`spkg_gap_pkg_curlinterface`
- :ref:`spkg_gap_pkg_float`
- :ref:`spkg_gap_pkg_jupyterkernel`
- :ref:`spkg_gap_pkg_normalizinterface`
- :ref:`spkg_glpk`
- :ref:`spkg_glucose`
- :ref:`spkg_gmp`
- :ref:`spkg_graphs`
- :ref:`spkg_highs`
- :ref:`spkg_kissat`
- :ref:`spkg_latte_int`
- :ref:`spkg_libbraiding`
- :ref:`spkg_libhomfly`
- :ref:`spkg_libpng`
- :ref:`spkg_lrslib`
- :ref:`spkg_m4ri`
- :ref:`spkg_m4rie`
- :ref:`spkg_mcqd`
- :ref:`spkg_mpc`
- :ref:`spkg_mpfr`
- :ref:`spkg_nauty`
- :ref:`spkg_palp`
- :ref:`spkg_pip`
- :ref:`spkg_planarity`
- :ref:`spkg_plantri`
- :ref:`spkg_rubiks`
- :ref:`spkg_rw`
- :ref:`spkg_semigroups`
- :ref:`spkg_symmetrica`
- :ref:`spkg_tachyon`
- :ref:`spkg_tdlib`


Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i _cibuildwheel_local_a


